=======
History
=======

0.1.7 (2023-10-26)
------------------

- turbocascade fixes: usable meshing algorithm
- dependency updates

0.1.6 (2023-10-13)
------------------

WITHDRAWN RELEASE

- productive meshing algorithm
- minor improvements

0.1.5 (2023-07-04)
------------------
- bugfixes alphashape
- initial gmsh intigration
- jupyternotebook testing
- improved codecov

0.1.4 (2023-06-25)
------------------
- cleaner structure, more reliability
- pypi deployment
- sphynx docs
- removed bugs

0.1.3 (2023-03-11)
------------------

* bug fixes
* implementation of a new timeseries stationarity analysis
* yplus postprocessing
* additional tests


0.1.2 (2022-20-12)
------------------

* meshquality methods
* example data sets
* jupyter notebook examples
